Struct crate_metadata_serde::SerializedSection
source · pub struct SerializedSection {
pub name: String,
pub ty: SectionType,
pub global: bool,
pub virtual_address: usize,
pub offset: usize,
pub size: usize,
}Expand description
A (de)serializable representation of a loaded section that is serde-compatible.
See LoadedSection for more detail on the fields of this struct.
Fields
name: StringThe full name of the section.
ty: SectionTypeThe type of the section.
global: boolWhether or not the section is global.
virtual_address: usizeThe starting virtual address of the range covered by this section.
offset: usizeThe offset into this section’s containing MappedPages where this section starts.
size: usizeThe size of the section.